==> renderdoc-1.11.tar.gz: renderdoc-1.11/renderdoc/data/resource.h <==
// clang-format off
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by renderdoc.rc
//
#define TYPE_EMBED          256

#define RESOURCE_misc_hlsl          101
#define RESOURCE_text_hlsl          102
#define RESOURCE_hlsl_cbuffers_h    103
#define RESOURCE_hlsl_texsample_h   104
#define RESOURCE_histogram_hlsl     105
#define RESOURCE_multisample_hlsl   106
#define RESOURCE_mesh_hlsl          107
#define RESOURCE_texdisplay_hlsl    108
#define RESOURCE_pixelhistory_hlsl  109
#define RESOURCE_quadoverdraw_hlsl  110
#define RESOURCE_texremap_hlsl      111
#define RESOURCE_fixedcol_hlsl      112

#define RESOURCE_fixedcol_0_dxbc    113
#define RESOURCE_fixedcol_1_dxbc    114
#define RESOURCE_fixedcol_2_dxbc    115
#define RESOURCE_fixedcol_3_dxbc    116
#define RESOURCE_quadwrite_dxbc     117

#define RESOURCE_sourcecodepro_ttf  301

#define RESOURCE_glsl_blit_vert                      401
#define RESOURCE_glsl_checkerboard_frag              402
#define RESOURCE_glsl_texdisplay_frag                403
#define RESOURCE_glsl_vktext_vert                    404
#define RESOURCE_glsl_vktext_frag                    405
#define RESOURCE_glsl_fixedcol_frag                  408
#define RESOURCE_glsl_mesh_vert                      409
#define RESOURCE_glsl_mesh_geom                      410
#define RESOURCE_glsl_mesh_frag                      411
#define RESOURCE_glsl_minmaxtile_comp                412
#define RESOURCE_glsl_minmaxresult_comp              413
#define RESOURCE_glsl_histogram_comp                 414
#define RESOURCE_glsl_glsl_ubos_h                    416
#define RESOURCE_glsl_gl_texsample_h                 417
#define RESOURCE_glsl_vk_texsample_h                 418
#define RESOURCE_glsl_quadresolve_frag               419
#define RESOURCE_glsl_quadwrite_frag                 420
#define RESOURCE_glsl_mesh_comp                      421
#define RESOURCE_glsl_array2ms_comp                  422
#define RESOURCE_glsl_ms2array_comp                  423
#define RESOURCE_glsl_trisize_geom                   424
#define RESOURCE_glsl_trisize_frag                   425
#define RESOURCE_glsl_deptharr2ms_frag               426
#define RESOURCE_glsl_depthms2arr_frag               427
#define RESOURCE_glsl_gles_texsample_h               428
#define RESOURCE_glsl_gltext_vert                    429
#define RESOURCE_glsl_gltext_frag                    430
#define RESOURCE_glsl_glsl_globals_h                 440
#define RESOURCE_glsl_texremap_frag                  441
#define RESOURCE_glsl_pixelhistory_mscopy_comp       442
#define RESOURCE_glsl_pixelhistory_mscopy_depth_comp 443
#define RESOURCE_glsl_pixelhistory_primid_frag       444
#define RESOURCE_glsl_shaderdebug_sample_vert        445
#define RESOURCE_glsl_discard_frag                   446

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        114
#define _APS_NEXT_COMMAND_VALUE         40029
#define _APS_NEXT_CONTROL_VALUE         1000
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

#include "api/replay/version.h"

==> renderdoc-1.36.tar.gz: renderdoc-1.36/renderdoc/data/resource.h <==
// clang-format off
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by renderdoc.rc
//
#define TYPE_EMBED          256

#define RESOURCE_misc_hlsl          101
#define RESOURCE_text_hlsl          102
#define RESOURCE_hlsl_cbuffers_h    103
#define RESOURCE_hlsl_texsample_h   104
#define RESOURCE_histogram_hlsl     105
#define RESOURCE_multisample_hlsl   106
#define RESOURCE_mesh_hlsl          107
#define RESOURCE_texdisplay_hlsl    108
#define RESOURCE_pixelhistory_hlsl  109
#define RESOURCE_quadoverdraw_hlsl  110
#define RESOURCE_texremap_hlsl      111
#define RESOURCE_fixedcol_hlsl      112
#define RESOURCE_shaderdebug_hlsl   118
#define RESOURCE_d3d12_pixelhistory_hlsl  119
#define RESOURCE_depth_copy_hlsl    120
#define RESOURCE_raytracing_hlsl    121

#define RESOURCE_fixedcol_0_dxbc    113
#define RESOURCE_fixedcol_1_dxbc    114
#define RESOURCE_fixedcol_2_dxbc    115
#define RESOURCE_fixedcol_3_dxbc    116
#define RESOURCE_quadwrite_dxbc     117
#define RESOURCE_pixelhistory_primitiveid_dxbc 122
#define RESOURCE_pixelhistory_fixedcol_0_dxbc  123
#define RESOURCE_pixelhistory_fixedcol_1_dxbc  124
#define RESOURCE_pixelhistory_fixedcol_2_dxbc  125
#define RESOURCE_pixelhistory_fixedcol_3_dxbc  126
#define RESOURCE_pixelhistory_fixedcol_4_dxbc  127
#define RESOURCE_pixelhistory_fixedcol_5_dxbc  128
#define RESOURCE_pixelhistory_fixedcol_6_dxbc  129
#define RESOURCE_pixelhistory_fixedcol_7_dxbc  130

#define RESOURCE_sourcecodepro_ttf  301

#define RESOURCE_glsl_blit_vert                      401
#define RESOURCE_glsl_checkerboard_frag              402
#define RESOURCE_glsl_texdisplay_frag                403
#define RESOURCE_glsl_vktext_vert                    404
#define RESOURCE_glsl_vktext_frag                    405
#define RESOURCE_glsl_fixedcol_frag                  408
#define RESOURCE_glsl_mesh_vert                      409
#define RESOURCE_glsl_mesh_geom                      410
#define RESOURCE_glsl_mesh_frag                      411
#define RESOURCE_glsl_minmaxtile_comp                412
#define RESOURCE_glsl_minmaxresult_comp              413
#define RESOURCE_glsl_histogram_comp                 414
#define RESOURCE_glsl_glsl_ubos_h                    416
#define RESOURCE_glsl_gl_texsample_h                 417
#define RESOURCE_glsl_vk_texsample_h                 418
#define RESOURCE_glsl_quadresolve_frag               419
#define RESOURCE_glsl_quadwrite_frag                 420
#define RESOURCE_glsl_mesh_comp                      421
#define RESOURCE_glsl_array2ms_comp                  422
#define RESOURCE_glsl_ms2array_comp                  423
#define RESOURCE_glsl_trisize_geom                   424
#define RESOURCE_glsl_trisize_frag                   425
#define RESOURCE_glsl_deptharr2ms_frag               426
#define RESOURCE_glsl_depthms2arr_frag               427
#define RESOURCE_glsl_gles_texsample_h               428
#define RESOURCE_glsl_gltext_vert                    429
#define RESOURCE_glsl_gltext_frag                    430
#define RESOURCE_glsl_glsl_globals_h                 440
#define RESOURCE_glsl_texremap_frag                  441
#define RESOURCE_glsl_pixelhistory_mscopy_comp       442
#define RESOURCE_glsl_pixelhistory_mscopy_depth_comp 443
#define RESOURCE_glsl_pixelhistory_primid_frag       444
#define RESOURCE_glsl_shaderdebug_sample_vert        445
#define RESOURCE_glsl_discard_frag                   446
#define RESOURCE_glsl_vk_ms2buffer_comp              447
#define RESOURCE_glsl_vk_depthms2buffer_comp         448
#define RESOURCE_glsl_vk_buffer2ms_comp              449
#define RESOURCE_glsl_vk_depthbuf2ms_frag		     450
#define RESOURCE_glsl_depth_copy_frag                451
#define RESOURCE_glsl_depth_copyms_frag              452

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        114
#define _APS_NEXT_COMMAND_VALUE         40029
#define _APS_NEXT_CONTROL_VALUE         1000
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

#include "api/replay/version.h"
